#[derive(FromFrame)]
{
// Attributes available to this derive:
#[frame]
}
Derives FromFrame for a struct, enabling deserialization from a Frame.
This derive generates code that references types from reifydb_type.
For code that references reifydb or reifydb_client, use the
FromFrame derive from those crates instead.
Attributes
#[frame(column = "name")]- Use a different column name than the field name#[frame(optional)]- Field is optional; missing columns or Undefined values become None#[frame(coerce)]- Use widening type coercion for this field#[frame(skip)]- Skip this field (must implement Default)